# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt6 UI code generator 6.5.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1000, 750)
        font = QtGui.QFont()
        font.setPointSize(9)
        MainWindow.setFont(font)
        self.centralwidget = QtWidgets.QWidget(parent=MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_Central = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_Central.setObjectName("gridLayout_Central")
        self.frameMiddle = QtWidgets.QFrame(parent=self.centralwidget)
        self.frameMiddle.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.frameMiddle.setFrameShadow(QtWidgets.QFrame.Shadow.Raised)
        self.frameMiddle.setObjectName("frameMiddle")
        self.gridLayout_Middle = QtWidgets.QGridLayout(self.frameMiddle)
        self.gridLayout_Middle.setObjectName("gridLayout_Middle")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.gridLayout_Middle.addLayout(self.gridLayout, 1, 0, 1, 1)
        self.labelFiles = QtWidgets.QLabel(parent=self.frameMiddle)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.labelFiles.setFont(font)
        self.labelFiles.setObjectName("labelFiles")
        self.gridLayout_Middle.addWidget(self.labelFiles, 0, 0, 1, 1)
        self.gridLayout_Central.addWidget(self.frameMiddle, 1, 0, 1, 1)
        self.frameTop = QtWidgets.QFrame(parent=self.centralwidget)
        self.frameTop.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.frameTop.setFrameShadow(QtWidgets.QFrame.Shadow.Raised)
        self.frameTop.setObjectName("frameTop")
        self.gridLayout_Top = QtWidgets.QGridLayout(self.frameTop)
        self.gridLayout_Top.setObjectName("gridLayout_Top")
        self.lineEdit_SourceFolder = QtWidgets.QLineEdit(parent=self.frameTop)
        self.lineEdit_SourceFolder.setObjectName("lineEdit_SourceFolder")
        self.gridLayout_Top.addWidget(self.lineEdit_SourceFolder, 0, 1, 1, 1)
        self.lineEdit_DestinationFolder = QtWidgets.QLineEdit(parent=self.frameTop)
        self.lineEdit_DestinationFolder.setObjectName("lineEdit_DestinationFolder")
        self.gridLayout_Top.addWidget(self.lineEdit_DestinationFolder, 1, 1, 1, 1)
        self.pushButton_BrowseSourceFolder = QtWidgets.QPushButton(parent=self.frameTop)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.pushButton_BrowseSourceFolder.setFont(font)
        self.pushButton_BrowseSourceFolder.setObjectName("pushButton_BrowseSourceFolder")
        self.gridLayout_Top.addWidget(self.pushButton_BrowseSourceFolder, 0, 2, 1, 1)
        self.label_DestinationFolder = QtWidgets.QLabel(parent=self.frameTop)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_DestinationFolder.setFont(font)
        self.label_DestinationFolder.setObjectName("label_DestinationFolder")
        self.gridLayout_Top.addWidget(self.label_DestinationFolder, 1, 0, 1, 1)
        self.label_SourceFolder = QtWidgets.QLabel(parent=self.frameTop)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.label_SourceFolder.setFont(font)
        self.label_SourceFolder.setObjectName("label_SourceFolder")
        self.gridLayout_Top.addWidget(self.label_SourceFolder, 0, 0, 1, 1)
        self.pushButton_ConversionOptions = QtWidgets.QPushButton(parent=self.frameTop)
        self.pushButton_ConversionOptions.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.pushButton_ConversionOptions.setFont(font)
        self.pushButton_ConversionOptions.setObjectName("pushButton_ConversionOptions")
        self.gridLayout_Top.addWidget(self.pushButton_ConversionOptions, 2, 2, 1, 1)
        self.pushButton_BrowseDestinationFolder = QtWidgets.QPushButton(parent=self.frameTop)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.pushButton_BrowseDestinationFolder.setFont(font)
        self.pushButton_BrowseDestinationFolder.setObjectName("pushButton_BrowseDestinationFolder")
        self.gridLayout_Top.addWidget(self.pushButton_BrowseDestinationFolder, 1, 2, 1, 1)
        self.comboBox_ConversionProfile = QtWidgets.QComboBox(parent=self.frameTop)
        self.comboBox_ConversionProfile.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.comboBox_ConversionProfile.setFont(font)
        self.comboBox_ConversionProfile.setObjectName("comboBox_ConversionProfile")
        self.comboBox_ConversionProfile.addItem("")
        self.comboBox_ConversionProfile.addItem("")
        self.comboBox_ConversionProfile.addItem("")
        self.comboBox_ConversionProfile.addItem("")
        self.comboBox_ConversionProfile.addItem("")
        self.comboBox_ConversionProfile.addItem("")
        self.comboBox_ConversionProfile.addItem("")
        self.gridLayout_Top.addWidget(self.comboBox_ConversionProfile, 2, 1, 1, 1)
        self.label_ConversionProfile = QtWidgets.QLabel(parent=self.frameTop)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.label_ConversionProfile.setFont(font)
        self.label_ConversionProfile.setObjectName("label_ConversionProfile")
        self.gridLayout_Top.addWidget(self.label_ConversionProfile, 2, 0, 1, 1)
        self.pushButton_Start = QtWidgets.QPushButton(parent=self.frameTop)
        self.pushButton_Start.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(9)
        self.pushButton_Start.setFont(font)
        self.pushButton_Start.setObjectName("pushButton_Start")
        self.gridLayout_Top.addWidget(self.pushButton_Start, 2, 3, 1, 1)
        self.gridLayout_Central.addWidget(self.frameTop, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(parent=MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionOpen_files = QtGui.QAction(parent=MainWindow)
        self.actionOpen_files.setObjectName("actionOpen_files")
        self.actionOpen_folder = QtGui.QAction(parent=MainWindow)
        self.actionOpen_folder.setObjectName("actionOpen_folder")
        self.actionExit = QtGui.QAction(parent=MainWindow)
        self.actionExit.setObjectName("actionExit")

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.lineEdit_SourceFolder, self.pushButton_BrowseSourceFolder)
        MainWindow.setTabOrder(self.pushButton_BrowseSourceFolder, self.lineEdit_DestinationFolder)
        MainWindow.setTabOrder(self.lineEdit_DestinationFolder, self.pushButton_BrowseDestinationFolder)
        MainWindow.setTabOrder(self.pushButton_BrowseDestinationFolder, self.comboBox_ConversionProfile)
        MainWindow.setTabOrder(self.comboBox_ConversionProfile, self.pushButton_ConversionOptions)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Font Converter"))
        self.labelFiles.setText(_translate("MainWindow", "Files"))
        self.pushButton_BrowseSourceFolder.setText(_translate("MainWindow", "Browse"))
        self.label_DestinationFolder.setText(_translate("MainWindow", "Destination folder"))
        self.label_SourceFolder.setText(_translate("MainWindow", "Source folder"))
        self.pushButton_ConversionOptions.setText(_translate("MainWindow", "Options"))
        self.pushButton_BrowseDestinationFolder.setText(_translate("MainWindow", "Browse"))
        self.comboBox_ConversionProfile.setCurrentText(_translate("MainWindow", "Select conversion profile"))
        self.comboBox_ConversionProfile.setItemText(0, _translate("MainWindow", "Select conversion profile"))
        self.comboBox_ConversionProfile.setItemText(1, _translate("MainWindow", "Web to SFNT"))
        self.comboBox_ConversionProfile.setItemText(2, _translate("MainWindow", "SFNT to Web"))
        self.comboBox_ConversionProfile.setItemText(3, _translate("MainWindow", "CFF to TrueType"))
        self.comboBox_ConversionProfile.setItemText(4, _translate("MainWindow", "TrueType to CFF"))
        self.comboBox_ConversionProfile.setItemText(5, _translate("MainWindow", "Variable to static"))
        self.comboBox_ConversionProfile.setItemText(6, _translate("MainWindow", "TTC to SFNT"))
        self.label_ConversionProfile.setText(_translate("MainWindow", "Conversion profile"))
        self.pushButton_Start.setText(_translate("MainWindow", "Convert"))
        self.actionOpen_files.setText(_translate("MainWindow", "Open files"))
        self.actionOpen_folder.setText(_translate("MainWindow", "Open folder"))
        self.actionExit.setText(_translate("MainWindow", "Exit"))
