# Form implementation generated from reading ui file 'sfnt2web_options_dialog.ui'
#
# Created by: PyQt6 UI code generator 6.5.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_sfnt2webOptions_Dialog(object):
    def setupUi(self, sfnt2webOptions_Dialog):
        sfnt2webOptions_Dialog.setObjectName("sfnt2webOptions_Dialog")
        sfnt2webOptions_Dialog.resize(400, 300)
        font = QtGui.QFont()
        font.setPointSize(9)
        sfnt2webOptions_Dialog.setFont(font)
        sfnt2webOptions_Dialog.setSizeGripEnabled(False)
        sfnt2webOptions_Dialog.setModal(False)
        self.gridLayout = QtWidgets.QGridLayout(sfnt2webOptions_Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=sfnt2webOptions_Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.RestoreDefaults|QtWidgets.QDialogButtonBox.StandardButton.Save)
        self.buttonBox.setCenterButtons(False)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 5, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 434, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout.addItem(spacerItem, 4, 0, 1, 1)
        self.overwrite_checkBox = QtWidgets.QCheckBox(parent=sfnt2webOptions_Dialog)
        self.overwrite_checkBox.setObjectName("overwrite_checkBox")
        self.gridLayout.addWidget(self.overwrite_checkBox, 2, 0, 1, 1)
        self.outputFormat_label = QtWidgets.QLabel(parent=sfnt2webOptions_Dialog)
        self.outputFormat_label.setObjectName("outputFormat_label")
        self.gridLayout.addWidget(self.outputFormat_label, 0, 0, 1, 1)
        self.outputFormat_comboBox = QtWidgets.QComboBox(parent=sfnt2webOptions_Dialog)
        self.outputFormat_comboBox.setObjectName("outputFormat_comboBox")
        self.outputFormat_comboBox.addItem("")
        self.outputFormat_comboBox.addItem("")
        self.outputFormat_comboBox.addItem("")
        self.gridLayout.addWidget(self.outputFormat_comboBox, 1, 0, 1, 1)
        self.recalcTimestamp_checkBox = QtWidgets.QCheckBox(parent=sfnt2webOptions_Dialog)
        self.recalcTimestamp_checkBox.setObjectName("recalcTimestamp_checkBox")
        self.gridLayout.addWidget(self.recalcTimestamp_checkBox, 3, 0, 1, 1)

        self.retranslateUi(sfnt2webOptions_Dialog)
        self.buttonBox.accepted.connect(sfnt2webOptions_Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(sfnt2webOptions_Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(sfnt2webOptions_Dialog)
        sfnt2webOptions_Dialog.setTabOrder(self.outputFormat_comboBox, self.overwrite_checkBox)
        sfnt2webOptions_Dialog.setTabOrder(self.overwrite_checkBox, self.recalcTimestamp_checkBox)

    def retranslateUi(self, sfnt2webOptions_Dialog):
        _translate = QtCore.QCoreApplication.translate
        sfnt2webOptions_Dialog.setWindowTitle(_translate("sfnt2webOptions_Dialog", "SFNT to Web options"))
        self.overwrite_checkBox.setText(_translate("sfnt2webOptions_Dialog", "Overwrite existing files"))
        self.outputFormat_label.setText(_translate("sfnt2webOptions_Dialog", "Output format"))
        self.outputFormat_comboBox.setItemText(0, _translate("sfnt2webOptions_Dialog", "WOFF + WOFF2"))
        self.outputFormat_comboBox.setItemText(1, _translate("sfnt2webOptions_Dialog", "WOFF"))
        self.outputFormat_comboBox.setItemText(2, _translate("sfnt2webOptions_Dialog", "WOFF2"))
        self.recalcTimestamp_checkBox.setText(_translate("sfnt2webOptions_Dialog", "Recalc timestamp"))
