# Form implementation generated from reading ui file 'output_dialog.ui'
#
# Created by: PyQt6 UI code generator 6.5.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Output(object):
    def setupUi(self, Output):
        Output.setObjectName("Output")
        Output.setWindowModality(QtCore.Qt.WindowModality.WindowModal)
        Output.resize(800, 600)
        font = QtGui.QFont()
        font.setPointSize(9)
        Output.setFont(font)
        Output.setAutoFillBackground(False)
        Output.setModal(False)
        self.verticalLayout = QtWidgets.QVBoxLayout(Output)
        self.verticalLayout.setObjectName("verticalLayout")
        self.plainTextEdit = QtWidgets.QPlainTextEdit(parent=Output)
        self.plainTextEdit.setEnabled(True)
        self.plainTextEdit.setAutoFillBackground(False)
        self.plainTextEdit.setReadOnly(True)
        self.plainTextEdit.setCenterOnScroll(False)
        self.plainTextEdit.setObjectName("plainTextEdit")
        self.verticalLayout.addWidget(self.plainTextEdit)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=Output)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Close|QtWidgets.QDialogButtonBox.StandardButton.Discard|QtWidgets.QDialogButtonBox.StandardButton.Reset)
        self.buttonBox.setCenterButtons(False)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(Output)
        self.buttonBox.accepted.connect(Output.accept) # type: ignore
        self.buttonBox.rejected.connect(Output.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Output)

    def retranslateUi(self, Output):
        _translate = QtCore.QCoreApplication.translate
        Output.setWindowTitle(_translate("Output", "Output"))
