# Form implementation generated from reading ui file 'otf2ttf_options_dialog.ui'
#
# Created by: PyQt6 UI code generator 6.5.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_otf2ttfOptions_Dialog(object):
    def setupUi(self, otf2ttfOptions_Dialog):
        otf2ttfOptions_Dialog.setObjectName("otf2ttfOptions_Dialog")
        otf2ttfOptions_Dialog.resize(400, 300)
        font = QtGui.QFont()
        font.setPointSize(9)
        otf2ttfOptions_Dialog.setFont(font)
        otf2ttfOptions_Dialog.setSizeGripEnabled(False)
        otf2ttfOptions_Dialog.setModal(False)
        self.gridLayout = QtWidgets.QGridLayout(otf2ttfOptions_Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(parent=otf2ttfOptions_Dialog)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.tolerance_doubleSpinBox = QtWidgets.QDoubleSpinBox(parent=otf2ttfOptions_Dialog)
        self.tolerance_doubleSpinBox.setDecimals(1)
        self.tolerance_doubleSpinBox.setMaximum(2.5)
        self.tolerance_doubleSpinBox.setSingleStep(0.1)
        self.tolerance_doubleSpinBox.setObjectName("tolerance_doubleSpinBox")
        self.horizontalLayout.addWidget(self.tolerance_doubleSpinBox)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 434, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout.addItem(spacerItem1, 3, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=otf2ttfOptions_Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.RestoreDefaults|QtWidgets.QDialogButtonBox.StandardButton.Save)
        self.buttonBox.setCenterButtons(False)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 4, 0, 1, 1)
        self.recalcTimestamp_checkBox = QtWidgets.QCheckBox(parent=otf2ttfOptions_Dialog)
        self.recalcTimestamp_checkBox.setObjectName("recalcTimestamp_checkBox")
        self.gridLayout.addWidget(self.recalcTimestamp_checkBox, 2, 0, 1, 1)
        self.overwrite_checkBox = QtWidgets.QCheckBox(parent=otf2ttfOptions_Dialog)
        self.overwrite_checkBox.setObjectName("overwrite_checkBox")
        self.gridLayout.addWidget(self.overwrite_checkBox, 1, 0, 1, 1)

        self.retranslateUi(otf2ttfOptions_Dialog)
        self.buttonBox.accepted.connect(otf2ttfOptions_Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(otf2ttfOptions_Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(otf2ttfOptions_Dialog)
        otf2ttfOptions_Dialog.setTabOrder(self.tolerance_doubleSpinBox, self.overwrite_checkBox)
        otf2ttfOptions_Dialog.setTabOrder(self.overwrite_checkBox, self.recalcTimestamp_checkBox)

    def retranslateUi(self, otf2ttfOptions_Dialog):
        _translate = QtCore.QCoreApplication.translate
        otf2ttfOptions_Dialog.setWindowTitle(_translate("otf2ttfOptions_Dialog", "OTF to TTF options"))
        self.label.setText(_translate("otf2ttfOptions_Dialog", "Conversion tolerance"))
        self.recalcTimestamp_checkBox.setText(_translate("otf2ttfOptions_Dialog", "Recalc timestamp"))
        self.overwrite_checkBox.setText(_translate("otf2ttfOptions_Dialog", "Overwrite existing files"))
