# Form implementation generated from reading ui file 'ttf2otf_options_dialog.ui'
#
# Created by: PyQt6 UI code generator 6.5.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ttf2otfOptions_Dialog(object):
    def setupUi(self, ttf2otfOptions_Dialog):
        ttf2otfOptions_Dialog.setObjectName("ttf2otfOptions_Dialog")
        ttf2otfOptions_Dialog.resize(400, 300)
        font = QtGui.QFont()
        font.setPointSize(9)
        ttf2otfOptions_Dialog.setFont(font)
        ttf2otfOptions_Dialog.setSizeGripEnabled(False)
        ttf2otfOptions_Dialog.setModal(False)
        self.gridLayout = QtWidgets.QGridLayout(ttf2otfOptions_Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.overwrite_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.overwrite_checkBox.setObjectName("overwrite_checkBox")
        self.gridLayout.addWidget(self.overwrite_checkBox, 8, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(parent=ttf2otfOptions_Dialog)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.tolerance_doubleSpinBox = QtWidgets.QDoubleSpinBox(parent=ttf2otfOptions_Dialog)
        self.tolerance_doubleSpinBox.setDecimals(1)
        self.tolerance_doubleSpinBox.setMaximum(2.5)
        self.tolerance_doubleSpinBox.setSingleStep(0.1)
        self.tolerance_doubleSpinBox.setObjectName("tolerance_doubleSpinBox")
        self.horizontalLayout.addWidget(self.tolerance_doubleSpinBox)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 0, 1, 1)
        self.safeMode_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.safeMode_checkBox.setObjectName("safeMode_checkBox")
        self.gridLayout.addWidget(self.safeMode_checkBox, 5, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 434, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout.addItem(spacerItem1, 10, 0, 1, 1)
        self.subroutinize_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.subroutinize_checkBox.setObjectName("subroutinize_checkBox")
        self.gridLayout.addWidget(self.subroutinize_checkBox, 2, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=ttf2otfOptions_Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.RestoreDefaults|QtWidgets.QDialogButtonBox.StandardButton.Save)
        self.buttonBox.setCenterButtons(False)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 11, 0, 1, 1)
        self.removeGlyphs_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.removeGlyphs_checkBox.setObjectName("removeGlyphs_checkBox")
        self.gridLayout.addWidget(self.removeGlyphs_checkBox, 1, 0, 1, 1)
        self.recalcTimestamp_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.recalcTimestamp_checkBox.setObjectName("recalcTimestamp_checkBox")
        self.gridLayout.addWidget(self.recalcTimestamp_checkBox, 9, 0, 1, 1)
        self.scaleUPM_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.scaleUPM_checkBox.setObjectName("scaleUPM_checkBox")
        self.gridLayout.addWidget(self.scaleUPM_checkBox, 7, 0, 1, 1)
        self.checkOutlines_checkBox = QtWidgets.QCheckBox(parent=ttf2otfOptions_Dialog)
        self.checkOutlines_checkBox.setObjectName("checkOutlines_checkBox")
        self.gridLayout.addWidget(self.checkOutlines_checkBox, 4, 0, 1, 1)

        self.retranslateUi(ttf2otfOptions_Dialog)
        self.buttonBox.accepted.connect(ttf2otfOptions_Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(ttf2otfOptions_Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(ttf2otfOptions_Dialog)
        ttf2otfOptions_Dialog.setTabOrder(self.tolerance_doubleSpinBox, self.removeGlyphs_checkBox)
        ttf2otfOptions_Dialog.setTabOrder(self.removeGlyphs_checkBox, self.subroutinize_checkBox)
        ttf2otfOptions_Dialog.setTabOrder(self.subroutinize_checkBox, self.safeMode_checkBox)
        ttf2otfOptions_Dialog.setTabOrder(self.safeMode_checkBox, self.overwrite_checkBox)
        ttf2otfOptions_Dialog.setTabOrder(self.overwrite_checkBox, self.recalcTimestamp_checkBox)

    def retranslateUi(self, ttf2otfOptions_Dialog):
        _translate = QtCore.QCoreApplication.translate
        ttf2otfOptions_Dialog.setWindowTitle(_translate("ttf2otfOptions_Dialog", "TTF to OTF options"))
        self.overwrite_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Overwrite existing files"))
        self.label.setText(_translate("ttf2otfOptions_Dialog", "Conversion tolerance (0-2.5)"))
        self.safeMode_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Safe mode"))
        self.subroutinize_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Subroutinize converted files"))
        self.removeGlyphs_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Remove .null and CR glyphs"))
        self.recalcTimestamp_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Recalc timestamp"))
        self.scaleUPM_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Scale UPM to 1000"))
        self.checkOutlines_checkBox.setToolTip(_translate("ttf2otfOptions_Dialog", "Performs optional outline quality checks and removes overlaps with afdko.checkoutlinesufo"))
        self.checkOutlines_checkBox.setText(_translate("ttf2otfOptions_Dialog", "Check outlines after conversion"))
